/********************************************************************************/
/*                                                                              */
/*  The following SAS code invokes the TITE-CRM macros.                         */
/*  See DEFAULTS macro in titecrm_v8.1.sas for most of the macro variables that */
/*  are set.  The variables set below are sufficiently important that you must  */
/*  understand what they mean before proceeding                                 */
/*                                                                              */
/*  The following files should be saved into the same directory in order to run */
/*  these examples:                                                             */
/*                              titecrm_v8.1.sas                                */
/*                              example_doses.dat                               */
/*                              example_patients.dat                            */
/*                              sim_doses.dat                                   */
/********************************************************************************/


%include "DIRECTORY\titecrm_v8.1.sas"
/* the word 'DIRECTORY' above and in the code below that follows, should be     */
/* replaced with the file directory on your computer where you have saved the   */
/* above files. One example could be C:\Program Files\SAS                       */



/********************************************************************************/
/*                                                                              */
/* Toxicity estimation from a trial example (README Mode 1) with fixed hazard   */
/* rate (uniform weighting)                                                     */
/*                                                                              */
/********************************************************************************/

                                    
%defaults

%let title1=%str(SINGLE TRIAL EXAMPLE);
%let simflag=0;
%let dosefile=%str(DIRECTORY\example_doses.dat);
%let obsdays=126;
%let level1=2;
%let target=0.15;

%let rscheme=13;
%let nproceed=2;
%let iflag=1;

%let vwflag=0;

%let patfile=%str(DIRECTORY\example_patients.dat);
%dday


%defdose

%patdata

%simtite


/********************************************************************************/
/*                                                                              */
/* Toxicity estimation from a trial example (README Mode 1) with variable       */
/* hazard                                                                       */
/*                                                                              */
/********************************************************************************/

%defaults

%let title1=%str(SINGLE TRIAL EXAMPLE WITH VARIABLE HAZARD);
%let simflag=0;
%let dosefile=%str(DIRECTORY\example_doses.dat);
%let obsdays=126;
%let level1=2;
%let target=0.15;

%let rscheme=13;
%let nproceed=2;
%let iflag=1;

%let vwflag=1;
%let vwdays=%str(21 42 63 84 105 126);
%let vwwts=%str(0.3 0.5 0.65 0.8 0.9 1.0);

%let patfile=%str(DIRECTORY\example_patients.dat);

%dday

%defdose

%patdata

%simtite

/********************************************************************************/
/*                                                                              */
/* Simulation example (README Mode 2), select dose LE target, 5 patient run-in  */
/*                                                                              */
/********************************************************************************/


%defaults

%let clearsim=1;

%let simflag=1;
%let debug=1;
%let dosefile=%str(DIRECTORY\sim_doses.dat);
%let obsdays=90;
%let level1=2;
%let target=0.25;
%let nrunin=5;

%let varcruit=0;
%let maxsub=30;
%let rectime=30;

%let rscheme=13;
%let nproceed=1;
%let iflag=1;

%let vwflag=0;
%let urflag=0;

%let seed1=3948573;
%let nsim=2;
%let simtag=sim1a;

%dday

%defdose

%simtite

/********************************************************************************/
/*                                                                              */
/* Simulation example (README Mode 2), dose closest to target, 0.10 max         */
/* overdose                                                                     */
/*                                                                              */
/********************************************************************************/


%defaults

%let clearsim=0;

%let simflag=1;
%let debug=1;
%let dosefile=%str(DIRECTORY\sim_doses.dat);
%let obsdays=90;
%let level1=2;
%let target=0.25;

%let varcruit=0;
%let maxsub=30;
%let rectime=30;

%let rscheme=13;
%let nproceed=1;
%let iflag=1;

%let vwflag=0;
%let urflag=0;

%let seed1=3948573;
%let nsim=2;
%let simtag=sim1b;

%let adm_dose=2;
%let adm_marg=0.10;

%dday

%defdose

%simtite


/********************************************************************************/
/*                                                                              */
/* Print out simulation results                                                 */
/*                                                                              */
/********************************************************************************/

ods pdf file='sim_results.pdf';

proc print uniform data=patient;
     title 'Patient-Level Simulation Results';
     run;

proc print uniform data=trial;
     title 'Trial-Level Simulation Results';
     run;
     quit;

ods pdf close;

